<?php

/**
 * @file
 * Functions needed for refresh elements list(statuses/categories).
 */

/**
 * Perform shape list of deleted items.
 *
 * @param array $new_items_list
 *   The new element list.
 * @param array $save_items_list
 *   The save element list in Drupal DB.
 * @param array $drupal_items_list
 *   The basic Drupal elements for Node.
 *   array[key] string
 *   The key has ID or Slug element value.
 * @param string $type
 *   The type elements in list.
 */
function desk_net_shape_deleted_items(array $new_items_list, array $save_items_list, array $drupal_items_list, $type) {
  $delete_element_list = array();

  if (!empty($save_items_list)) {
    foreach ($save_items_list as $id => $value) {
      $in_stock = FALSE;
      foreach ($new_items_list as $key => $content) {
        if ($save_items_list[$id]["id"] == $new_items_list[$key]["id"]) {
          $in_stock = TRUE;
        }
      }

      if (!$in_stock) {
        array_push($delete_element_list, $save_items_list[$id]['id']);
      }
    }
  }
  if (!empty($delete_element_list)) {
    $delete_element_list = desk_net_check_sub_items($delete_element_list, $save_items_list);
    desk_net_delete_items($delete_element_list, $drupal_items_list, $type);
  }
}

/**
 * Perform checking parent elements in the list of elements to be deleted.
 *
 * @param array $delete_element_list
 *   The element for delete from saved list.
 * @param array $save_items_list
 *   The save element list in Drupal DB.
 *
 * @return array
 *   The list with deleting elements.
 */
function desk_net_check_sub_items(array $delete_element_list, array $save_items_list) {
  $under_sub_category = array();

  if (!empty($save_items_list)) {
    foreach ($save_items_list as $key => $item) {
      foreach ($delete_element_list as $value) {
        if (isset($save_items_list[$key]["category"]) && $value == $save_items_list[$key]["category"]) {
          array_push($delete_element_list, $save_items_list[$key]['id']);
          array_push($under_sub_category, $save_items_list[$key]['id']);
        }
      }
    }
  }
  if (!empty($under_sub_category)) {
    $result = desk_net_check_sub_items($under_sub_category, $save_items_list);

    return $result;
  }
  else {
    return $delete_element_list;
  }
}

/**
 * Perform deleted items and mapping category.
 *
 * @param array $delete_element_list
 *   The element for delete from saved list.
 * @param array $drupal_items_list
 *   The basic Drupal elements for Node.
 * @param string $type
 *   The type elements in list.
 */
function desk_net_delete_items(array $delete_element_list, array $drupal_items_list, $type) {
  if (!empty($drupal_items_list) && !empty($delete_element_list)) {
    foreach ($delete_element_list as $content) {
      foreach ($drupal_items_list as $value) {
        if ($content == desk_net_variable_get('desk_net_' . $type . '_drupal_to_desk_net_' . $value)) {
          desk_net_variable_set('desk_net_' . $type . '_drupal_to_desk_net_' . $value, 'no_' . $type);
        }
      }
      desk_net_variable_del('desk_net_' . $type . '_desk_net_to_drupal_' . $content);
    }
  }
}
